﻿using System;
using System.Net;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Documents;
using System.Windows.Ink;
using System.Windows.Input;
using System.Windows.Media;
using System.Windows.Media.Animation;
using System.Windows.Shapes;
using System.Collections.ObjectModel;
using Infragistics.Controls.Schedules;
using Infragistics.Controls.Schedules.Primitives;
using System.ComponentModel;

namespace ScheduleSample
{
    public class ScheduleData
    {
        private ObservableCollection<Resource> _resources = new ObservableCollection<Resource>();
        private ObservableCollection<ResourceCalendar> _resourceCalendars = new ObservableCollection<ResourceCalendar>();
        private ObservableCollection<MyAppointment> _MyAppointments = new ObservableCollection<MyAppointment>();

        public ObservableCollection<Resource> Resources
        {
            get { return _resources; }
            set { _resources = value; }
        }

        public ObservableCollection<ResourceCalendar> ResourceCalendars
        {
            get { return _resourceCalendars; }
            set { _resourceCalendars = value; }
        }

        public ObservableCollection<MyAppointment> MyAppointments
        {
            get { return _MyAppointments; }
            set { _MyAppointments = value; }
        }

        public ScheduleData()
        {
            InitializeData();
        }

        private void InitializeData()
        {
            #region Initialize users

            Resource user1 = new Resource { Name = "User 1", Id = "user1" };
            Resource user2 = new Resource { Name = "User 2", Id = "user2" };
            this.Resources.Add(user1);
            this.Resources.Add(user2);

            #endregion // Initialize users

            #region Initialize calendars

            ResourceCalendar user1Calendar1 = new ResourceCalendar { Name = "User1 Calendar1", OwningResourceId = "user1", Id = "user1Calendar1" };
            ResourceCalendar user1Calendar2 = new ResourceCalendar { Name = "User1 Calendar2", OwningResourceId = "user1", Id = "user1Calendar2" };
            ResourceCalendar user2Calendar1 = new ResourceCalendar { Name = "User2 Calendar1", OwningResourceId = "user2", Id = "user2Calendar1" };
            this.ResourceCalendars.Add(user1Calendar1);
            this.ResourceCalendars.Add(user1Calendar2);
            this.ResourceCalendars.Add(user2Calendar1);

            #endregion //Initialize calendars

            #region InitializeMyAppointments

            MyAppointment user1MyAppointment1 = new MyAppointment { Id = "user1MyAppointment1", OwningResourceId = "user1", OwningCalendarId = "user1Calendar1" };
            user1MyAppointment1.Subject = "User1 First MyAppointment";
            user1MyAppointment1.Start = new DateTime(DateTime.Now.Year, DateTime.Now.Month, DateTime.Now.Day, 9, 0, 0);
            user1MyAppointment1.End = new DateTime(DateTime.Now.Year, DateTime.Now.Month, DateTime.Now.Day, 11, 0, 0);
            user1MyAppointment1.BarColor = Brushes.Red;

            MyAppointment user1MyAppointment2 = new MyAppointment { Id = "user1MyAppointment2", OwningResourceId = "user1", OwningCalendarId = "user1Calendar1" };
            user1MyAppointment2.Subject = "User1 Second MyAppointment";
            user1MyAppointment2.Start = new DateTime(DateTime.Now.Year, DateTime.Now.Month, DateTime.Now.Day, 11, 0, 0);
            user1MyAppointment2.End = new DateTime(DateTime.Now.Year, DateTime.Now.Month, DateTime.Now.Day, 12, 0, 0);
            user1MyAppointment2.BarColor = Brushes.Blue;

            MyAppointment user1MyAppointment3 = new MyAppointment { Id = "user1MyAppointment3", OwningResourceId = "user1", OwningCalendarId = "user1Calendar1" };
            user1MyAppointment3.Subject = "User1 Third MyAppointment";
            user1MyAppointment3.Start = new DateTime(DateTime.Now.Year, DateTime.Now.Month, DateTime.Now.Day, 11, 0, 0);
            user1MyAppointment3.End = new DateTime(DateTime.Now.Year, DateTime.Now.Month, DateTime.Now.Day, 12, 0, 0);

            MyAppointment user1MyAppointment4 = new MyAppointment { Id = "user1MyAppointment4", OwningResourceId = "user1", OwningCalendarId = "user1Calendar2" };
            user1MyAppointment4.Subject = "User1 Fourth MyAppointment";
            user1MyAppointment4.Start = new DateTime(DateTime.Now.Year, DateTime.Now.Month, DateTime.Now.Day, 11, 0, 0);
            user1MyAppointment4.End = new DateTime(DateTime.Now.Year, DateTime.Now.Month, DateTime.Now.Day, 12, 0, 0);

            MyAppointment user1MyAppointment5 = new MyAppointment { Id = "user1MyAppointment5", OwningResourceId = "user1", OwningCalendarId = "user1Calendar2" };
            user1MyAppointment5.Subject = "User1 Fifth MyAppointment";
            user1MyAppointment5.Start = new DateTime(DateTime.Now.Year, DateTime.Now.Month, DateTime.Now.Day, 11, 0, 0);
            user1MyAppointment5.End = new DateTime(DateTime.Now.Year, DateTime.Now.Month, DateTime.Now.Day, 12, 0, 0);

            MyAppointment user1MyAppointment6 = new MyAppointment { Id = "user1MyAppointment6", OwningResourceId = "user1", OwningCalendarId = "user1Calendar2" };
            user1MyAppointment6.Subject = "User1 Sixth MyAppointment";
            user1MyAppointment6.Start = new DateTime(DateTime.Now.Year, DateTime.Now.Month, DateTime.Now.Day, 9, 0, 0);
            user1MyAppointment6.End = new DateTime(DateTime.Now.Year, DateTime.Now.Month, DateTime.Now.Day, 11, 0, 0);

            MyAppointment user2MyAppointment1 = new MyAppointment { Id = "user2MyAppointment1", OwningResourceId = "user2", OwningCalendarId = "user2Calendar1" };
            user2MyAppointment1.Subject = "User2 First MyAppointment";
            user2MyAppointment1.Start = new DateTime(DateTime.Now.Year, DateTime.Now.Month, DateTime.Now.Day, 9, 0, 0);
            user2MyAppointment1.End = new DateTime(DateTime.Now.Year, DateTime.Now.Month, DateTime.Now.Day, 11, 0, 0);

            MyAppointment user2MyAppointment2 = new MyAppointment { Id = "user2MyAppointment2", OwningResourceId = "user2", OwningCalendarId = "user2Calendar1" };
            user2MyAppointment2.Subject = "User2 Second MyAppointment";
            user2MyAppointment2.Start = new DateTime(DateTime.Now.Year, DateTime.Now.Month, DateTime.Now.Day, 11, 0, 0);
            user2MyAppointment2.End = new DateTime(DateTime.Now.Year, DateTime.Now.Month, DateTime.Now.Day, 12, 0, 0);

            this.MyAppointments.Add(user1MyAppointment1);
            this.MyAppointments.Add(user1MyAppointment2);
            this.MyAppointments.Add(user1MyAppointment3);
            this.MyAppointments.Add(user1MyAppointment4);
            this.MyAppointments.Add(user1MyAppointment5);
            this.MyAppointments.Add(user1MyAppointment6);
            this.MyAppointments.Add(user2MyAppointment1);
            this.MyAppointments.Add(user2MyAppointment2);
            
            #endregion //InitializeMyAppointments
        }
    }


    public class MyAppointment : INotifyPropertyChanged
    {
        private string description;
        private string id;
        private bool? isLocked;
        private bool isOccurrenceDeleted;
        private bool isTimeZoneNeutral;
        private bool? isVisible;
        private DateTime? maxOccurrenceDateTime;
        private DateTime originalOccurrenceEnd;
        private DateTime originalOccurrenceStart;
        private string owningCalendarId;
        private string owningResourceId;
        private string recurrence;
        private string reminder;
        private TimeSpan reminderInterval;
        private string rootActivityId;
        private DateTime start;
        private string startTimeZoneId;
        private string subject;
        private string unmappedProperties;
        private DateTime end;
        private string endTimeZoneId;
        private string location;
        private long variantProperties;
        private int recurrenceVersion;
        private bool reminderEnabled;
        private Brush barColor;

        public string Description
        {
            get { return description; }
            set
            {
                if (this.Description == value)
                    return;

                description = value;
                this.RaisePropertyChanged("Description");
            }
        }

        public string Id
        {
            get { return id; }
            set
            {
                if (this.Id == value)
                    return;

                id = value;
                this.RaisePropertyChanged("Id");
            }
        }

        public bool? IsLocked
        {
            get { return isLocked; }
            set
            {
                if (this.IsLocked == value)
                    return;

                isLocked = value;
                this.RaisePropertyChanged("IsLocked");
            }
        }

        public bool IsOccurrenceDeleted
        {
            get { return isOccurrenceDeleted; }
            set
            {
                if (this.IsOccurrenceDeleted == value)
                    return;

                isOccurrenceDeleted = value;
                this.RaisePropertyChanged("IsOccurrenceDeleted");
            }
        }

        public bool IsTimeZoneNeutral
        {
            get { return isTimeZoneNeutral; }
            set
            {
                if (this.IsTimeZoneNeutral == value)
                    return;

                isTimeZoneNeutral = value;
                this.RaisePropertyChanged("IsTimeZoneNeutral");
            }
        }

        public bool? IsVisible
        {
            get { return isVisible; }
            set
            {
                if (this.IsVisible == value)
                    return;

                isVisible = value;
                this.RaisePropertyChanged("IsVisible");
            }
        }

        public DateTime? MaxOccurrenceDateTime
        {
            get { return maxOccurrenceDateTime; }
            set
            {
                if (this.MaxOccurrenceDateTime == value)
                    return;

                maxOccurrenceDateTime = value;
                this.RaisePropertyChanged("MaxOccurrenceDateTime");
            }
        }

        public DateTime OriginalOccurrenceEnd
        {
            get { return originalOccurrenceEnd; }
            set
            {
                if (this.OriginalOccurrenceEnd == value)
                    return;

                originalOccurrenceEnd = value;
                this.RaisePropertyChanged("OriginalOccurrenceEnd");
            }
        }

        public DateTime OriginalOccurrenceStart
        {
            get { return originalOccurrenceStart; }
            set
            {
                if (this.OriginalOccurrenceStart == value)
                    return;

                originalOccurrenceStart = value;
                this.RaisePropertyChanged("OriginalOccurrenceStart");
            }
        }

        public string OwningCalendarId
        {
            get { return owningCalendarId; }
            set
            {
                if (this.OwningCalendarId == value)
                    return;

                owningCalendarId = value;
                this.RaisePropertyChanged("OwningCalendarId");
            }
        }

        public string OwningResourceId
        {
            get { return owningResourceId; }
            set
            {
                if (this.OwningResourceId == value)
                    return;

                owningResourceId = value;
                this.RaisePropertyChanged("OwningResourceId");
            }
        }

        public string Recurrence
        {
            get { return recurrence; }
            set
            {
                if (this.Recurrence == value)
                    return;

                recurrence = value;
                this.RaisePropertyChanged("Recurrence");
            }
        }

        public string Reminder
        {
            get { return reminder; }
            set
            {
                if (this.Reminder == value)
                    return;

                reminder = value;
                this.RaisePropertyChanged("Reminder");
            }
        }

        public TimeSpan ReminderInterval
        {
            get { return reminderInterval; }
            set
            {
                if (this.ReminderInterval == value)
                    return;

                reminderInterval = value;
                this.RaisePropertyChanged("ReminderInterval");
            }
        }

        public string RootActivityId
        {
            get { return rootActivityId; }
            set
            {
                if (this.RootActivityId == value)
                    return;

                rootActivityId = value;
                this.RaisePropertyChanged("RootActivityId");
            }
        }

        public DateTime Start
        {
            get { return start; }
            set
            {
                if (this.Start == value)
                    return;

                start = value;
                this.RaisePropertyChanged("Start");
            }
        }

        public string StartTimeZoneId
        {
            get { return startTimeZoneId; }
            set
            {
                if (this.StartTimeZoneId == value)
                    return;

                startTimeZoneId = value;
                this.RaisePropertyChanged("StartTimeZoneId");
            }
        }

        public string Subject
        {
            get { return subject; }
            set
            {
                if (this.Subject == value)
                    return;

                subject = value;
                this.RaisePropertyChanged("Subject");
            }
        }

        public string UnmappedProperties
        {
            get { return unmappedProperties; }
            set
            {
                if (this.UnmappedProperties == value)
                    return;

                unmappedProperties = value;
                this.RaisePropertyChanged("UnmappedProperties");
            }
        }

        public DateTime End
        {
            get { return end; }
            set
            {
                if (this.End == value)
                    return;

                end = value;
                this.RaisePropertyChanged("End");
            }
        }

        public string EndTimeZoneId
        {
            get { return endTimeZoneId; }
            set
            {
                if (this.EndTimeZoneId == value)
                    return;

                endTimeZoneId = value;
                this.RaisePropertyChanged("EndTimeZoneId");
            }
        }

        public string Location
        {
            get { return location; }
            set
            {
                if (this.Location == value)
                    return;

                location = value;
                this.RaisePropertyChanged("Location");
            }
        }

        public long VariantProperties
        {
            get { return variantProperties; }
            set
            {
                if (this.VariantProperties == value)
                    return;

                variantProperties = value;
                this.RaisePropertyChanged("VariantProperties");
            }
        }

        public int RecurrenceVersion
        {
            get { return recurrenceVersion; }
            set
            {
                if (this.RecurrenceVersion == value)
                    return;

                recurrenceVersion = value;
                this.RaisePropertyChanged("RecurrenceVersion");
            }
        }

        public bool ReminderEnabled
        {
            get { return reminderEnabled; }
            set
            {
                if (this.ReminderEnabled == value)
                    return;

                reminderEnabled = value;
                this.RaisePropertyChanged("ReminderEnabled");
            }
        }

        public Brush BarColor
        {
            get
            {
                return barColor;
            }
            set
            {
                barColor = value;
                this.RaisePropertyChanged("BarColor");
            }
        }

        public event PropertyChangedEventHandler PropertyChanged;

        private void RaisePropertyChanged(string propertyName)
        {
            if (this.PropertyChanged != null)
                this.PropertyChanged(this, new PropertyChangedEventArgs(propertyName));
        }
        

    }
}
